@@ -89,10 +89,8 @@ class json():
         asn_filename = asn.asn_name
         if not asn_filename.endswith('.json'):
             asn_filename = asn_filename+'.json'
-        return (
-            asn_filename,
-            json_lib.dumps(asn.data, cls=AssociationEncoder, indent=4, separators=(',', ': '))
-        )
+        return (asn_filename,
+            json_lib.dumps(asn.data, cls=AssociationEncoder, indent=4, separators=(',', ': ')))
 
 
 @Association.ioregistry
@@ -155,10 +153,7 @@ class yaml():
         asn_filename = asn.asn_name
         if not asn.asn_name.endswith('.yaml'):
             asn_filename = asn.asn_name+'.yaml'
-        return (
-            asn_filename,
-            yaml_lib.dump(asn.data, default_flow_style=False)
-        )
+        return (asn_filename, yaml_lib.dump(asn.data, default_flow_style=False))
 
 
 # Register YAML representers
