@@ -69,11 +69,20 @@ class Asn_Lv2Image(
             Constraint_Base(),
             Constraint_Mode(),
             Constraint_Image_Science(),
-            Constraint_Single_Science(self.has_science),
             Constraint(
                 [Constraint_TSO()],
                 reduce=Constraint.notany
-            )
+            ),
+            Constraint(
+                [
+                    SimpleConstraint(
+                        value='background',
+                        test=lambda value, item: self.get_exposure_type(item) == value,
+                        force_unique=False,
+                    ),
+                    Constraint_Single_Science(self.has_science),
+                ], reduce=Constraint.any
+            ),
         ])
 
         # Now check and continue initialization.
@@ -102,22 +111,6 @@ class Asn_Lv2ImageNonScience(
             Constraint_Base(),
             Constraint_Image_Nonscience(),
             Constraint_Single_Science(self.has_science),
-            Constraint(
-                [
-                    DMSAttrConstraint(
-                        name='dms_note',
-                        sources=['dms_note'],
-                        value=['wfsc_los_jitter'],
-                    ),
-                    DMSAttrConstraint(
-                        name='exp_type',
-                        sources=['exp_type'],
-                        value='nrc_image'
-                    ),
-
-                ],
-                reduce=Constraint.notall
-            )
         ])
 
         # Now check and continue initialization.
@@ -984,6 +977,22 @@ class Asn_Lv2WFSC(
             Constraint_Image_Science(),
             Constraint_Single_Science(self.has_science),
             Constraint_WFSC(),
+            Constraint(
+                [
+                    DMSAttrConstraint(
+                        name='dms_note',
+                        sources=['dms_note'],
+                        value=['wfsc_los_jitter'],
+                    ),
+                    DMSAttrConstraint(
+                        name='exp_type',
+                        sources=['exp_type'],
+                        value='nrc_image'
+                    ),
+
+                ],
+                reduce=Constraint.notall
+            )
         ])
 
         # Now check and continue initialization.
