@@ -32,6 +32,8 @@ class CubeBuildStep (Step):
 
     """
 
+    class_alias = "cube_build"
+
     spec = """
          channel = option('1','2','3','4','all',default='all') # Channel
          band = option('short','medium','long','short-medium','short-long','medium-short', \
@@ -42,7 +44,7 @@ class CubeBuildStep (Step):
          scale1 = float(default=0.0) # cube sample size to use for axis 1, arc seconds
          scale2 = float(default=0.0) # cube sample size to use for axis 2, arc seconds
          scalew = float(default=0.0) # cube sample size to use for axis 3, microns
-         weighting = option('emsm','msm','drizzle',default = 'emsm') # Type of weighting function
+         weighting = option('emsm','msm','drizzle',default = 'drizzle') # Type of weighting function
          coord_system = option('skyalign','world','internal_cal','ifualign',default='skyalign') # Output Coordinate system.
          rois = float(default=0.0) # region of interest spatial size, arc seconds
          roiw = float(default=0.0) # region of interest wavelength size, microns
@@ -75,24 +77,24 @@ class CubeBuildStep (Step):
         self.subchannel = self.band
         self.suffix = 's3d'  # override suffix = cube_build
 
-        if(not self.subchannel.islower()):
+        if not self.subchannel.islower():
             self.subchannel = self.subchannel.lower()
-        if(not self.filter.islower()):
+        if not self.filter.islower():
             self.filter = self.filter.lower()
-        if(not self.grating.islower()):
+        if not self.grating.islower():
             self.grating = self.grating.lower()
-        if(not self.coord_system.islower()):
+        if not self.coord_system.islower():
             self.coord_system = self.coord_system.lower()
-        if(not self.output_type.islower()):
+        if not self.output_type.islower():
             self.output_type = self.output_type.lower()
-        if(not self.weighting.islower()):
+        if not self.weighting.islower():
             self.weighting = self.weighting.lower()
 
-        if(self.scale1 != 0.0):
+        if self.scale1 != 0.0:
             self.log.info(f'Input Scale of axis 1 {self.scale1}')
-        if(self.scale2 != 0.0):
+        if self.scale2 != 0.0:
             self.log.info(f'Input Scale of axis 2 {self.scale2}')
-        if(self.scalew != 0.0):
+        if self.scalew != 0.0:
             self.log.info(f'Input wavelength scale {self.scalew}')
 
         if self.wavemin is not None:
@@ -117,6 +119,7 @@ class CubeBuildStep (Step):
         # coord system = internal_cal only option for weighting = area
         if self.coord_system == 'internal_cal':
             self.interpolation = 'area'
+            self.weighting = 'emsm'
 
         # if interpolation is point cloud then weighting can be
         # 1. MSM: modified Shepard method
@@ -159,12 +162,19 @@ class CubeBuildStep (Step):
             self.pars_input['output_type'] = 'single'
             self.log.info('Cube Type: Single cubes')
             self.pars_input['coord_system'] = 'skyalign'
-            self.interpolation = 'pointcloud'
 
-            # Don't allow anything but msm or emsm weightings
-            if ((self.weighting != 'msm') and (self.weighting != 'emsm')):
-                self.weighting = 'emsm'
+            # Don't allow anything but drizzle, msm, or emsm weightings
+            if self.weighting not in ['msm', 'emsm', 'drizzle']:
+                self.weighting = 'drizzle'
 
+            if self.weighting == 'drizzle':
+                self.interpolation = 'drizzle'
+
+            if self.weighting == 'msm':
+                self.interpolation = 'pointcloud'
+
+            if self.weighting == 'emsm':
+                self.interpolation = 'pointcloud'
 
 # read_user_input:
 # see if options channel, band,grating filter are set on the command lines
@@ -336,7 +346,6 @@ class CubeBuildStep (Step):
         for cube in cube_container:
             footprint = cube.meta.wcs.footprint(axis_type="spatial")
             update_s_region_keyword(cube, footprint)
-            cube.meta.filetype = '3d ifu cube'
 
             # remove certain WCS keywords that are irrelevant after combine data into IFUCubes
             for key in rm_keys:
@@ -381,7 +390,7 @@ class CubeBuildStep (Step):
             user_clen = len(channellist)
             for j in range(user_clen):
                 ch = channellist[j]
-                if(user_clen > 1):
+                if user_clen > 1:
                     ch = ch.strip('[')
                     ch = ch.strip(']')
                     ch = ch.strip(' ')
