@@ -5,6 +5,8 @@ import os.path as op
 import re
 import logging
 
+import numpy as np
+
 from asdf import AsdfFile
 from astropy.io import fits
 from stdatamodels import DataModel, properties
@@ -17,6 +19,8 @@ __doctest_skip__ = ['ModelContainer']
 
 __all__ = ['ModelContainer']
 
+_ONE_MB = 1 << 20
+
 # Configure logging
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
@@ -72,6 +76,22 @@ class ModelContainer(JwstDataModel, Sequence):
     >>> c = ModelContainer()
     >>> m = datamodels.open('myfile.fits')
     >>> c.append(m)
+
+    Notes
+    -----
+        The optional paramters ``save_open`` and ``return_open`` can be provided
+        to control how the DataModels are used by the ModelContainer.
+        If ``save_open`` is set to `False`,
+        each input DataModel instance in ``init`` will be written out to disk and closed,
+        then only the filename for the
+        DataModel will be used to initialize the ModelContainer object.  Subsequent
+        access of each member will then open the DataModel file to work with it.  If
+        ``return_open`` is also `False`, then the DataModel will be closed when
+        access to the DataModel is completed.  The use of these parameters can
+        minimize the amount of memory used by this object during processing, with
+        these parameters being used by :py:class:`~jwst.outlier_detection.OutlierDetectionStep`.
+
+
     """
     schema_url = None
 
@@ -89,15 +109,23 @@ class ModelContainer(JwstDataModel, Sequence):
         self.asn_pool_name = None
 
         self._memmap = kwargs.get("memmap", False)
+        self._return_open = kwargs.get('return_open', True)
+        self._save_open = kwargs.get('save_open', True)
 
         if init is None:
             # Don't populate the container with models
             pass
         elif isinstance(init, fits.HDUList):
-            self._models.append([datamodel_open(init, memmap=self._memmap)])
+            if self._save_open:
+                model = [datamodel_open(init, memmap=self._memmap)]
+            else:
+                model = init._file.name
+                init.close()
+            self._models.append(model)
         elif isinstance(init, list):
             if all(isinstance(x, (str, fits.HDUList, DataModel)) for x in init):
-                init = [datamodel_open(m, memmap=self._memmap) for m in init]
+                if self._save_open:
+                    init = [datamodel_open(m, memmap=self._memmap) for m in init]
             else:
                 raise TypeError("list must contain items that can be opened "
                                 "with jwst.datamodels.open()")
@@ -124,7 +152,10 @@ class ModelContainer(JwstDataModel, Sequence):
         return len(self._models)
 
     def __getitem__(self, index):
-        return self._models[index]
+        m = self._models[index]
+        if not isinstance(m, DataModel) and self._return_open:
+            m = datamodel_open(m, memmap=self._memmap)
+        return m
 
     def __setitem__(self, index, model):
         self._models[index] = model
@@ -134,6 +165,8 @@ class ModelContainer(JwstDataModel, Sequence):
 
     def __iter__(self):
         for model in self._models:
+            if not isinstance(model, DataModel) and self._return_open:
+                model = datamodel_open(model, memmap=self._memmap)
             yield model
 
     def insert(self, index, model):
@@ -228,7 +261,11 @@ class ModelContainer(JwstDataModel, Sequence):
             sublist = infiles
         try:
             for filepath in sublist:
-                self._models.append(datamodel_open(filepath, memmap=self._memmap))
+                if self._save_open:
+                    m = datamodel_open(filepath, memmap=self._memmap)
+                else:
+                    m = filepath
+                self._models.append(m)
         except IOError:
             self.close()
             raise
@@ -308,11 +345,12 @@ class ModelContainer(JwstDataModel, Sequence):
 
             else:
                 output_paths.append(save_model_func(model, idx=idx))
-
         return output_paths
 
-    def _assign_group_ids(self):
+    @property
+    def models_grouped(self):
         """
+        Returns a list of a list of datamodels grouped by exposure.
         Assign an ID grouping by exposure.
 
         Data from different detectors of the same exposure will have the
@@ -337,8 +375,12 @@ class ModelContainer(JwstDataModel, Sequence):
             'exposure_number'
         ]
 
+        group_dict = OrderedDict()
         for i, model in enumerate(self._models):
             params = []
+            if not self._save_open:
+                model = datamodel_open(model, memmap=self._memmap)
+
             for param in unique_exposure_parameters:
                 params.append(getattr(model.meta.observation, param))
             try:
@@ -348,19 +390,16 @@ class ModelContainer(JwstDataModel, Sequence):
             except TypeError:
                 model.meta.group_id = 'exposure{0:04d}'.format(i + 1)
 
-    @property
-    def models_grouped(self):
-        """
-        Returns a list of a list of datamodels grouped by exposure.
-        """
-        self._assign_group_ids()
-        group_dict = OrderedDict()
-        for model in self._models:
             group_id = model.meta.group_id
+            if not self._save_open and not self._return_open:
+                model.close()
+                model = self._models[i]
+
             if group_id in group_dict:
                 group_dict[group_id].append(model)
             else:
                 group_dict[group_id] = [model]
+
         return group_dict.values()
 
     @property
@@ -377,7 +416,8 @@ class ModelContainer(JwstDataModel, Sequence):
         """Close all datamodels."""
         if not self._iscopy:
             for model in self._models:
-                model.close()
+                if isinstance(model, DataModel):
+                    model.close()
 
     @property
     def crds_observatory(self):
@@ -437,14 +477,88 @@ class ModelContainer(JwstDataModel, Sequence):
         ind : list
             Indices of models in ModelContainer._models matching ``asn_exptype``.
         """
+        names = []
+        for m in self.meta.asn_table.products[0].members:
+            if m.exptype.lower() == asn_exptype:
+                file_path, file_name = op.split(m.expname)
+                names.append(file_name)
         ind = []
-        names = [m.expname for m in self.meta.asn_table.products[0].members
-                 if m.exptype.lower() == asn_exptype]
         for i, model in enumerate(self._models):
             if model.meta.filename in names:
                 ind.append(i)
         return ind
 
+    def set_buffer(self, buffer_size, overlap=None):
+        """Set buffer size for scrolling section-by-section access.
+
+        Parameters
+        ----------
+        buffer_size : float, None
+            Define size of buffer in MB for each section.
+            If `None`, a default buffer size of 1MB will be used.
+
+        overlap : int, optional
+            Define the number of rows of overlaps between sections.
+            If `None`, no overlap will be used.
+        """
+        self.overlap = 0 if overlap is None else overlap
+        self.grow = 0
+
+        with datamodel_open(self._models[0]) as model:
+            imrows, imcols = model.data.shape
+            data_item_size = model.data.itemsize
+            data_item_type = model.data.dtype
+            model.close()
+        del model
+        min_buffer_size = imcols * data_item_size
+
+        self.buffer_size = min_buffer_size if buffer_size is None else (buffer_size * _ONE_MB)
+
+        section_nrows = min(imrows, int(self.buffer_size // min_buffer_size))
+
+        if section_nrows == 0:
+            self.buffer_size = min_buffer_size
+            logger.warning("WARNING: Buffer size is too small to hold a single row."
+                           f"Increasing buffer size to {self.buffer_size / _ONE_MB}MB")
+            section_nrows = 1
+
+        nbr = section_nrows - self.overlap
+        nsec = (imrows - self.overlap) // nbr
+        if (imrows - self.overlap) % nbr > 0:
+            nsec += 1
+
+        self.n_sections = nsec
+        self.nbr = nbr
+        self.section_nrows = section_nrows
+        self.imrows = imrows
+        self.imcols = imcols
+        self.imtype = data_item_type
+
+    def get_sections(self):
+        """Iterator to return the sections from all members of the container."""
+
+        for k in range(self.n_sections):
+            e1 = k * self.nbr
+            e2 = e1 + self.section_nrows
+
+            if k == self.n_sections - 1:  # last section
+                e2 = min(e2, self.imrows)
+                e1 = min(e1, e2 - self.overlap - 1)
+
+            data_list = np.empty((len(self._models), e2 - e1, self.imcols),
+                                 dtype=self.imtype)
+            wht_list = np.empty((len(self._models), e2 - e1, self.imcols),
+                                dtype=self.imtype)
+            for i, model in enumerate(self._models):
+                model = datamodel_open(model, memmap=self._memmap)
+
+                data_list[i, :, :] = model.data[e1:e2].copy()
+                wht_list[i, :, :] = model.wht[e1:e2].copy()
+                model.close()
+                del model
+
+            yield (data_list, wht_list, (e1, e2))
+
 
 def make_file_with_index(file_path, idx):
     """Append an index to a filename
