@@ -271,9 +271,10 @@ def extract_grism_objects(input_model,
                           grism_objects=None,
                           reference_files=None,
                           extract_orders=None,
-                          mmag_extract=99.,
+                          mmag_extract=None,
                           compute_wavelength=True,
-                          wfss_extract_half_height=None):
+                          wfss_extract_half_height=None,
+                          nbright=None):
     """
     Extract 2d boxes around each objects spectra for each order.
 
@@ -302,6 +303,9 @@ def extract_grism_objects(input_model,
         Cross-dispersion extraction half height in pixels, WFSS mode.
         Overwrites the computed extraction height.
 
+    nbright : int
+        Number of brightest objects to extract for WFSS mode.
+
     Returns
     -------
     output_model : `~jwst.datamodels.MultiSlitModel`
@@ -318,10 +322,13 @@ def extract_grism_objects(input_model,
     boxes that will be used to define the 2d extraction area.
 
     For each spectral order, the configuration file contains a
-    magnitude-cutoff value. Sources with magnitudes fainter than the
-    extraction cutoff (MMAG_EXTRACT)  will not be extracted, but are
+    magnitude-cutoff value. The total list of objects to extract is limited
+    by both MMAG_EXTRACT and NBRIGHT. Sources with magnitudes fainter than the
+    extraction cutoff (MMAG_EXTRACT) will not be extracted, but are
     accounted for when computing the spectral contamination and background
-    estimates. The default extraction value is 99 right now.
+    estimates. The default value is 99 right now.
+    NBRIGHT further limits the list to the NBRIGHT brightest objects.
+    The default value is 999 right now.
 
     The sensitivity information from the original aXe style configuration
     file needs to be modified by the passband of the filter used for
@@ -352,13 +359,15 @@ def extract_grism_objects(input_model,
 
     if grism_objects is None:
         # get the wavelengthrange reference file from the input_model
-        if ('wavelengthrange' not in reference_files or reference_files['wavelengthrange'] in ['N/A', '']):
+        if ('wavelengthrange' not in reference_files or
+                reference_files['wavelengthrange'] in ['N/A', '']):
             raise ValueError("Expected name of wavelengthrange reference file")
         else:
             grism_objects = util.create_grism_bbox(input_model, reference_files,
                                                    extract_orders=extract_orders,
                                                    mmag_extract=mmag_extract,
-                                                   wfss_extract_half_height=wfss_extract_half_height)
+                                                   wfss_extract_half_height=wfss_extract_half_height,
+                                                   nbright=nbright)
             log.info("Grism object list created from source catalog: {0:s}"
                      .format(input_model.meta.source_catalog))
 
@@ -367,7 +376,7 @@ def extract_grism_objects(input_model,
     if len(grism_objects) == 0:
         raise ValueError("No grism objects created from source catalog")
 
-    log.info("Extracting grism objects into MultiSlitModel")
+    log.info("Extracting %d grism objects", len(grism_objects))
     output_model = datamodels.MultiSlitModel()
     output_model.update(input_model)
 
@@ -402,6 +411,7 @@ def extract_grism_objects(input_model,
             # The bounding boxes here are also limited to the size of the detector
             # The check for boxes entirely off the detector is done in create_grism_bbox right now
             y, x = obj.order_bounding[order]
+            log.debug(f'YYY, {y}, {clamp(y[0], 0, input_model.meta.subarray.ysize)}')
 
             # limit the boxes to the detector
             ymin = clamp(y[0], 0, input_model.meta.subarray.ysize)
@@ -412,7 +422,7 @@ def extract_grism_objects(input_model,
             # don't extract anything that ended up with zero dimensions in one axis
             # this means that it was identified as a partial order but only on one
             # row or column of the detector
-            if (((ymax - ymin) > 0) and ((xmax - xmin) > 0)):
+            if ymax - ymin > 0 and xmax - xmin > 0:
                 subwcs = copy.deepcopy(inwcs)
                 log.info("Subarray extracted for obj: {} order: {}:".format(obj.sid, order))
                 log.info("Subarray extents are: "
@@ -436,20 +446,22 @@ def extract_grism_objects(input_model,
                                                  xcenter_model &
                                                  ycenter_model &
                                                  order_model) | tr
-
-                ext_data = input_model.data[ymin: ymax + 1, xmin: xmax + 1].copy()
-                ext_err = input_model.err[ymin: ymax + 1, xmin: xmax + 1].copy()
-                ext_dq = input_model.dq[ymin: ymax + 1, xmin: xmax + 1].copy()
+                from gwcs.utils import _toindex
+                y_slice = slice(_toindex(ymin), _toindex(ymax))
+                x_slice = slice(_toindex(xmin), _toindex(xmax))
+                ext_data = input_model.data[y_slice, x_slice].copy()
+                ext_err = input_model.err[y_slice, x_slice].copy()
+                ext_dq = input_model.dq[y_slice, x_slice].copy()
                 if input_model.var_poisson is not None and np.size(input_model.var_poisson) > 0:
-                    var_poisson = input_model.var_poisson[ymin:ymax + 1, xmin:xmax + 1].copy()
+                    var_poisson = input_model.var_poisson[y_slice, x_slice].copy()
                 else:
                     var_poisson = None
                 if input_model.var_rnoise is not None and np.size(input_model.var_rnoise) > 0:
-                    var_rnoise = input_model.var_rnoise[ymin:ymax + 1, xmin:xmax + 1].copy()
+                    var_rnoise = input_model.var_rnoise[y_slice, x_slice].copy()
                 else:
                     var_rnoise = None
                 if input_model.var_flat is not None and np.size(input_model.var_flat) > 0:
-                    var_flat = input_model.var_flat[ymin:ymax + 1, xmin:xmax + 1].copy()
+                    var_flat = input_model.var_flat[y_slice, x_slice].copy()
                 else:
                     var_flat = None
 
@@ -477,9 +489,9 @@ def extract_grism_objects(input_model,
                 # nslit = obj.sid - 1  # catalog id starts at zero
                 new_slit.name = "{0}".format(obj.sid)
                 new_slit.is_extended = obj.is_extended
-                new_slit.xstart = xmin + 1  # fits pixels
+                new_slit.xstart = _toindex(xmin) + 1  # fits pixels
                 new_slit.xsize = ext_data.shape[1]
-                new_slit.ystart = ymin + 1  # fits pixels
+                new_slit.ystart = _toindex(ymin) + 1  # fits pixels
                 new_slit.ysize = ext_data.shape[0]
                 new_slit.source_xpos = float(obj.xcentroid)
                 new_slit.source_ypos = float(obj.ycentroid)
