@@ -74,8 +74,8 @@ def do_correction(input_model,
     # NIRSpec spectrographic data are processed differently from other
     # types of data (including NIRSpec imaging).  The test on flat is
     # needed because NIRSpec imaging data are processed by do_flat_field().
-    if (input_model.meta.exposure.type in NIRSPEC_SPECTRAL_EXPOSURES) and \
-            (input_model.meta.instrument.lamp_mode != 'IMAGE'):
+    if ((input_model.meta.exposure.type in NIRSPEC_SPECTRAL_EXPOSURES) and
+            (input_model.meta.instrument.lamp_mode != 'IMAGE')):
         flat_applied = do_nirspec_flat_field(output_model, fflat, sflat, dflat,
                                              user_supplied_flat=user_supplied_flat,
                                              inverse=inverse)
@@ -119,8 +119,8 @@ def do_flat_field(output_model, flat_model, inverse=False):
     any_updated = False  # will set True if any flats applied
 
     # Check to see if flat data array is smaller than science data
-    if (output_model.data.shape[-1] > flat_model.data.shape[-1]) or \
-            (output_model.data.shape[-2] > flat_model.data.shape[-2]):
+    if ((output_model.data.shape[-1] > flat_model.data.shape[-1]) or
+            (output_model.data.shape[-2] > flat_model.data.shape[-2])):
         log.warning('Reference data array is smaller than science data')
         log.warning('Step will be skipped')
 
@@ -191,6 +191,11 @@ def apply_flat_field(science, flat, inverse=False):
     flat_zero = np.where(flat_data == 0.)
     flat_dq[flat_zero] = np.bitwise_or(flat_dq[flat_zero], bad_flag)
 
+    # Find pixels in the flat that have the DQ bit for NO_FLAT_FIELD set
+    # Set the DO_NOT_USE flag for such pixels
+    flat_noflat = np.where(np.bitwise_and(flat_dq, dqflags.pixel['NO_FLAT_FIELD']))
+    flat_dq[flat_noflat] = np.bitwise_or(flat_dq[flat_noflat], dqflags.pixel['DO_NOT_USE'])
+
     # Find all pixels in the flat that have a DQ value of DO_NOT_USE
     flat_bad = np.bitwise_and(flat_dq, dqflags.pixel['DO_NOT_USE'])
 
@@ -844,7 +849,7 @@ def spectrograph_flat(wl, s_flat_model,
     quadrant = None
 
     if xstart >= xstop or ystart >= ystop:
-        return (1., None)
+        return 1., None
 
     (tab_wl, tab_flat) = read_flat_table(s_flat_model, exposure_type,
                                          slit_name, quadrant)
@@ -951,7 +956,7 @@ def detector_flat(wl, d_flat_model,
     quadrant = None
 
     if xstart >= xstop or ystart >= ystop:
-        return (1., None)
+        return 1., None
 
     (tab_wl, tab_flat) = read_flat_table(d_flat_model, exposure_type,
                                          slit_name, quadrant)
@@ -1020,6 +1025,8 @@ def combine_dq(f_flat_dq, s_flat_dq, d_flat_dq, default_shape):
         The DQ array resulting from combining the input DQ arrays via
         bitwise OR.
     """
+    BADFLAT = dqflags.pixel['NO_FLAT_FIELD'] | dqflags.pixel['DO_NOT_USE']
+    BADFLAT = BADFLAT | dqflags.pixel['UNRELIABLE_FLAT']
 
     dq_list = []
     if f_flat_dq is not None:
@@ -1030,33 +1037,23 @@ def combine_dq(f_flat_dq, s_flat_dq, d_flat_dq, default_shape):
         dq_list.append(d_flat_dq)
     n_dq = len(dq_list)
 
-    # When a combination of flats are used the pixel dq flag is set to DO_NOTUSE only
-    # if all flags have DO_NOT_USE for that pixel
-
+    # Combine the component flat dq arrays.  If there are none, make a
+    # dq array with all BADFLAT bits set
     flat_dq = np.zeros(default_shape, dtype=np.uint32)
-    if n_dq == 1:
-        flat_dq = dq_list[0].copy()
-    elif n_dq == 2:
-        flat_dq = np.bitwise_or(dq_list[0], dq_list[1])
-        bad1 = np.bitwise_and(dq_list[0], dqflags.pixel['DO_NOT_USE'])
-        bad2 = np.bitwise_and(dq_list[1], dqflags.pixel['DO_NOT_USE'])
-        iflag = np.where((bad1 == 1) & (bad2 == 1))
-    elif n_dq == 3:
-        temp = np.bitwise_or(dq_list[0], dq_list[1])
-        flat_dq = np.bitwise_or(temp, dq_list[2])
-        bad1 = np.bitwise_and(dq_list[0], dqflags.pixel['DO_NOT_USE'])
-        bad2 = np.bitwise_and(dq_list[1], dqflags.pixel['DO_NOT_USE'])
-        bad3 = np.bitwise_and(dq_list[2], dqflags.pixel['DO_NOT_USE'])
-        iflag = np.where((bad1 == 1) & (bad2 == 1) & (bad3 == 1))
+    if n_dq == 0:
+        flat_dq = np.bitwise_or(flat_dq, BADFLAT)
+    else:
+        for dq_component in dq_list:
+            flat_dq = np.bitwise_or(flat_dq, dq_component)
 
-    # if flats is a combination of 2 or more flats:
-    # only flag DO_NOT_USE if all the flats had do not other
-    # otherwise flat as UNRELIABLE_FLAT
-    if n_dq >= 2:
-        iloc = np.where(np.bitwise_and(flat_dq, dqflags.pixel['DO_NOT_USE']))
-        flat_dq[iloc] = dqflags.pixel['UNRELIABLE_FLAT']
-        # now only set DO_NOT_USE to pixels that are set in both flats as DO_NOT_USE
-        flat_dq[iflag] = np.bitwise_or(flat_dq[iflag], dqflags.pixel['DO_NOT_USE'])
+    # Flag DO_NOT_USE where some or all of the flats had NO_FLAT_FIELD set
+    do_not_use_loc = np.where(np.bitwise_and(flat_dq, dqflags.pixel['NO_FLAT_FIELD']))
+    flat_dq[do_not_use_loc] = np.bitwise_or(flat_dq[do_not_use_loc], dqflags.pixel['DO_NOT_USE'])
+
+    # Flag DO_NOT_USE, NO_FLAT_FIELD and UNRELIABLE_FLAT where some or all the
+    # flats had DO_NOT_USE set
+    iloc = np.where(np.bitwise_and(flat_dq, dqflags.pixel['DO_NOT_USE']))
+    flat_dq[iloc] = np.bitwise_or(flat_dq[iloc], BADFLAT)
 
     return flat_dq
 
@@ -1247,7 +1244,7 @@ def read_flat_table(flat_model, exposure_type, slit_name=None, quadrant=None):
             log.warning("Wavelengths in the fast-variation table "
                         "must be strictly increasing.")
 
-    return (tab_wl, tab_flat)
+    return tab_wl, tab_flat
 
 
 def combine_fast_slow(wl, flat_2d, flat_dq, tab_wl, tab_flat, dispaxis):
@@ -1332,7 +1329,7 @@ def combine_fast_slow(wl, flat_2d, flat_dq, tab_wl, tab_flat, dispaxis):
                 else:
                     values[j, i] = temp
 
-    return (flat_2d * values, combined_dq)
+    return flat_2d * values, combined_dq
 
 
 def clean_wl(wl, dispaxis):
@@ -1527,11 +1524,9 @@ def interpolate_flat(image_flat, image_dq, image_err, image_wl, wl):
             # dq and err arrays are the same size, so treat them the same
             return image_flat.reshape((ysize, xsize)), image_dq, image_err
         else:
-            return (
-                image_flat.reshape((ysize, xsize)),
-                image_dq.reshape((ysize, xsize)),
-                image_err.reshape((ysize, xsize))
-            )
+            return (image_flat.reshape((ysize, xsize)),
+                    image_dq.reshape((ysize, xsize)),
+                    image_err.reshape((ysize, xsize)))
 
     grid = np.indices((ysize, xsize), dtype=np.intp)
     ixpixel = grid[1]
