@@ -22,10 +22,16 @@ class JumpStep(Step):
         flag_4_neighbors = boolean(default=True) # flag the four perpendicular neighbors of each CR
         max_jump_to_flag_neighbors = float(default=1000) # maximum jump sigma that will trigger neighbor flagging
         min_jump_to_flag_neighbors = float(default=10) # minimum jump sigma that will trigger neighbor flagging
+        after_jump_flag_dn1 = float(default=0) # 1st flag groups after jump above DN threshold
+        after_jump_flag_time1 = float(default=0) # 1st flag groups after jump groups within specified time
+        after_jump_flag_dn2 = float(default=0) # 2nd flag groups after jump above DN threshold
+        after_jump_flag_time2 = float(default=0) # 2nd flag groups after jump groups within specified time
     """
 
     reference_file_types = ['gain', 'readnoise']
 
+    class_alias = 'jump'
+
     def process(self, input):
 
         with datamodels.RampModel(input) as input_model:
@@ -47,6 +53,10 @@ class JumpStep(Step):
             max_jump_to_flag_neighbors = self.max_jump_to_flag_neighbors
             min_jump_to_flag_neighbors = self.min_jump_to_flag_neighbors
             flag_4_neighbors = self.flag_4_neighbors
+            after_jump_flag_dn1 = self.after_jump_flag_dn1
+            after_jump_flag_time1 = self.after_jump_flag_time1
+            after_jump_flag_dn2 = self.after_jump_flag_dn2
+            after_jump_flag_time2 = self.after_jump_flag_time2
 
             self.log.info('CR rejection threshold = %g sigma', rej_thresh)
             if self.maximum_cores != 'none':
@@ -68,7 +78,11 @@ class JumpStep(Step):
             result = run_detect_jumps(input_model, gain_model, readnoise_model,
                                       rej_thresh, three_grp_rej_thresh, four_grp_rej_thresh, max_cores,
                                       max_jump_to_flag_neighbors, min_jump_to_flag_neighbors,
-                                      flag_4_neighbors)
+                                      flag_4_neighbors,
+                                      after_jump_flag_dn1,
+                                      after_jump_flag_time1,
+                                      after_jump_flag_dn2,
+                                      after_jump_flag_time2)
             gain_model.close()
             readnoise_model.close()
             tstop = time.time()
