@@ -373,7 +373,8 @@ class TransformParameters:
         return r
 
 
-def add_wcs(filename, allow_any_file=False, default_pa_v3=0., siaf_path=None, engdb_url=None,
+def add_wcs(filename, allow_any_file=False, force_level1bmodel=False,
+            default_pa_v3=0., siaf_path=None, engdb_url=None,
             fgsid=None, tolerance=60, allow_default=False, reduce_func=None,
             dry_run=False, save_transforms=None, **transform_kwargs):
     """Add WCS information to a JWST DataModel.
@@ -394,6 +395,10 @@ def add_wcs(filename, allow_any_file=False, default_pa_v3=0., siaf_path=None, en
         The default, `False`, only allows modifications of files that contain
         known datamodels of `Level1bmodel`, `ImageModel`, or `CubeModel`.
 
+    force_level1bmodel : bool
+        If not `allow_any_file`, and the input file model is unknown,
+        open the input file as a Level1bModel regardless.
+
     default_pa_v3 : float
         The V3 position angle to use if the pointing information
         is not found.
@@ -472,7 +477,16 @@ def add_wcs(filename, allow_any_file=False, default_pa_v3=0., siaf_path=None, en
 
     """
     logger.info('Updating WCS info for file %s', filename)
-    with datamodels.open(filename, guess=allow_any_file) as model:
+    try:
+        model = datamodels.open(filename, guess=allow_any_file)
+    except TypeError:
+        if force_level1bmodel:
+            logger.warning(f'Input {filename} is an unknown model, opening as a Level1bModel.')
+            model = datamodels.Level1bModel(filename)
+        else:
+            raise
+
+    try:
         if type(model) not in EXPECTED_MODELS:
             logger.warning(f'Input {model} is not of an expected type (uncal, rate, rateints)'
                            '\n    Updating pointing may have no effect or detrimental effects on the WCS information,'
@@ -509,6 +523,8 @@ def add_wcs(filename, allow_any_file=False, default_pa_v3=0., siaf_path=None, en
             if transforms and save_transforms:
                 logger.info('Saving transform matrices to %s', save_transforms)
                 transforms.write_to_asdf(save_transforms)
+    finally:
+        model.close()
 
     logger.info('...update completed')
 
@@ -1244,15 +1260,7 @@ def calc_attitude_matrix(wcs, yangle, position):
     v3 = pos_rads[1]
 
     # Create the matrices
-    r1 = np.array([
-        [cos(ra) * cos(dec), sin(ra) * cos(dec), sin(dec)],
-        [(-sin(ra) * cos(yangle_ra)) + (cos(ra) * sin(dec) * sin(yangle_ra)),
-         (cos(ra) * cos(yangle_ra)) + (sin(ra) * sin(dec) * sin(yangle_ra)),
-         -cos(dec) * sin(yangle_ra)],
-        [(-sin(ra) * sin(yangle_ra)) - (cos(ra) * sin(dec) * cos(yangle_ra)),
-         (cos(ra) * sin(yangle_ra)) - (sin(ra) * sin(dec) * cos(yangle_ra)),
-         cos(dec) * cos(yangle_ra)]
-    ])
+    r1 = dcm(ra, dec, yangle_ra)
 
     r2 = np.array([
         [cos(v2) * cos(v3), -sin(v2), -cos(v2) * sin(v3)],
@@ -1498,20 +1506,7 @@ def calc_v2siaf_matrix(siaf):
     """
     v2, v3, v3idlyang, vparity = (siaf.v2_ref, siaf.v3_ref,
                                   siaf.v3yangle, siaf.vparity)
-    v2 *= A2R
-    v3 *= A2R
-    v3idlyang *= D2R
-
-    mat = np.array(
-        [[cos(v3) * cos(v2),
-          cos(v3) * sin(v2),
-          sin(v3)],
-         [-cos(v3idlyang) * sin(v2) + sin(v3idlyang) * sin(v3) * cos(v2),
-          cos(v3idlyang) * cos(v2) + sin(v3idlyang) * sin(v3) * sin(v2),
-          -sin(v3idlyang) * cos(v3)],
-         [-sin(v3idlyang) * sin(v2) - cos(v3idlyang) * sin(v3) * cos(v2),
-          sin(v3idlyang) * cos(v2) - cos(v3idlyang) * sin(v3) * sin(v2),
-          cos(v3idlyang) * cos(v3)]])
+    mat = dcm(v2 * A2R, v3 * A2R, v3idlyang * D2R)
     pmat = np.array([[0., vparity, 0.],
                      [0., 0., 1.],
                      [1., 0., 0.]])
@@ -1647,7 +1642,7 @@ def vector_to_angle(v):
     delta = np.arcsin(v[2])
     if alpha < 0.:
         alpha += 2. * np.pi
-    return(alpha, delta)
+    return alpha, delta
 
 
 def angle_to_vector(alpha, delta):
@@ -2512,3 +2507,39 @@ def t_pars_from_model(model, **t_pars_kwargs):
     t_pars.pointing = pointing
 
     return t_pars
+
+
+def dcm(alpha, delta, angle):
+    """Construct the Direction Cosine Matrix (DCM)
+
+    Typical usage is passing of (RA, DEC, PositionAngle).
+    All values must be in radians.
+
+    Parameters
+    ----------
+    alpha : float
+        First coordinate in radians.
+
+    delta : float
+        Second coordinate in radians.
+
+    angle : float
+        Position angle in radians.
+
+    Returns
+    -------
+    dcm : nd.array((3, 3))
+        The 3x3 direction cosine matrix
+    """
+    dcm = np.array(
+        [[cos(delta) * cos(alpha),
+          cos(delta) * sin(alpha),
+          sin(delta)],
+         [-cos(angle) * sin(alpha) + sin(angle) * sin(delta) * cos(alpha),
+          cos(angle) * cos(alpha) + sin(angle) * sin(delta) * sin(alpha),
+          -sin(angle) * cos(delta)],
+         [-sin(angle) * sin(alpha) - cos(angle) * sin(delta) * cos(alpha),
+          sin(angle) * cos(alpha) - cos(angle) * sin(delta) * sin(alpha),
+          cos(angle) * cos(delta)]])
+
+    return dcm
