@@ -91,7 +91,7 @@ def test_coeff_dq():
 
     # check that multiplication of polynomial was done correctly for specified pixel
     outval = L0 + (L1 * scival) + (L2 * scival**2) + (L3 * scival**3) + (L4 * scival**4)
-    assert(np.isclose(outfile.data[0, 45, 30, 50], outval, rtol=0.00001))
+    assert np.isclose(outfile.data[0, 45, 30, 50], outval, rtol=0.00001)
 
     # check that dq value was handled correctly
     assert outfile.pixeldq[35, 35] == dqflags.pixel['DO_NOT_USE']
@@ -166,8 +166,8 @@ def test_nolincorr():
     # run through pipeline (saturation and linearity steps)
     outfile = lincorr(im, ref_model)
 
-    assert(outfile.pixeldq[500, 500] == dqflags.pixel['NO_LIN_CORR'])
-    assert(outfile.data[0, 5, 500, 500] == 35)  # NO_LIN_CORR, sci value should not change
+    assert outfile.pixeldq[500, 500] == dqflags.pixel['NO_LIN_CORR']
+    assert outfile.data[0, 5, 500, 500] == 35  # NO_LIN_CORR, sci value should not change
 
 
 def test_pixeldqprop():
@@ -217,11 +217,12 @@ def test_pixeldqprop():
     # run through linearity correction
     outfile = lincorr(im, ref_model)
 
-    assert(outfile.pixeldq[500, 500] == dqflags.pixel['NO_LIN_CORR'])
-    assert(outfile.pixeldq[550, 550] == dqflags.pixel['DO_NOT_USE'])
-    assert(outfile.pixeldq[560, 550] == dqflags.pixel['HOT'])
-    assert(outfile.pixeldq[550, 560] == dqflags.pixel['DEAD'])
-    assert(outfile.pixeldq[500, 300] == np.bitwise_or(dqflags.pixel['HOT'], dqflags.pixel['DO_NOT_USE']))
+    assert outfile.pixeldq[500, 500] == dqflags.pixel['NO_LIN_CORR']
+    assert outfile.pixeldq[550, 550] == dqflags.pixel['DO_NOT_USE']
+    assert outfile.pixeldq[560, 550] == dqflags.pixel['HOT']
+    assert outfile.pixeldq[550, 560] == dqflags.pixel['DEAD']
+    assert outfile.pixeldq[500, 300] == np.bitwise_or(
+        dqflags.pixel['HOT'], dqflags.pixel['DO_NOT_USE'])
 
 
 def test_lin_subarray():
@@ -285,8 +286,8 @@ def test_lin_subarray():
     outpixdq = outfile.pixeldq
 
     # check for dq flag in pixeldq of subarray image
-    assert(outpixdq[76, 100] == 1)
-    assert(outpixdq[76, 104] == 1)
+    assert (outpixdq[76, 100] == 1)
+    assert (outpixdq[76, 104] == 1)
 
 
 def test_err_array():
