@@ -42,7 +42,7 @@ class GuiderPipeline(Pipeline):
         # If the first two steps are set to be skipped, assume
         # they've been run before and open the input as a Cal
         # model, appropriate for input to flat_field
-        if (self.dq_init.skip and self.guider_cds.skip):
+        if self.dq_init.skip and self.guider_cds.skip:
             log.info("dq_init and guider_cds are set to skip; assume they"
                      " were run before and load data as GuiderCalModel")
             input = datamodels.GuiderCalModel(input)
@@ -54,8 +54,6 @@ class GuiderPipeline(Pipeline):
         input = self.guider_cds(input)
         input = self.flat_field(input)
 
-        input.meta.filetype = 'countrate'
-
         log.info('... ending calwebb_guider')
 
         return input
