@@ -329,7 +329,7 @@ def dodrizzle(insci, input_wcs, inwht, output_wcs, outsci, outwht, outcon,
     else:
         expscale = expin
 
-    if (insci.dtype > np.float32):
+    if insci.dtype > np.float32:
         insci = insci.astype(np.float32)
 
     # Add input weight image if it was not passed in
