@@ -39,7 +39,7 @@ class ResampleData:
     """
 
     def __init__(self, input_models, output=None, single=False, blendheaders=True,
-                 pixfrac=1.0, kernel="square", fillval="INDEF", weight_type="ivm",
+                 pixfrac=1.0, kernel="square", fillval="INDEF", wht_type="ivm",
                  good_bits=0, pscale_ratio=1.0, pscale=None, **kwargs):
         """
         Parameters
@@ -55,6 +55,13 @@ class ResampleData:
 
             .. note::
                 ``output_shape`` is in the ``x, y`` order.
+
+            .. note::
+                ``in_memory`` controls whether or not the resampled
+                array from ``resample_many_to_many()``
+                should be kept in memory or written out to disk and
+                deleted from memory. Default value is `True` to keep
+                all products in memory.
         """
         self.input_models = input_models
 
@@ -65,8 +72,14 @@ class ResampleData:
         self.pixfrac = pixfrac
         self.kernel = kernel
         self.fillval = fillval
-        self.weight_type = weight_type
+        self.weight_type = wht_type
         self.good_bits = good_bits
+        self.in_memory = kwargs.get('in_memory', True)
+
+        log.info(f"Driz parameter kernel: {self.kernel}")
+        log.info(f"Driz parameter pixfrac: {self.pixfrac}")
+        log.info(f"Driz parameter fillval: {self.fillval}")
+        log.info(f"Driz parameter weight_type: {self.weight_type}")
 
         ref_wcs = kwargs.get('ref_wcs', None)
         out_shape = kwargs.get('out_shape', None)
@@ -88,6 +101,7 @@ class ResampleData:
             crpix=crpix,
             crval=crval
         )
+
         log.debug('Output mosaic size: {}'.format(self.output_wcs.array_shape))
         can_allocate, required_memory = datamodels.util.check_memory_allocation(
             self.output_wcs.array_shape, kwargs['allowed_memory'], datamodels.ImageModel
@@ -104,7 +118,7 @@ class ResampleData:
         self.blank_output.update(input_models[0])
         self.blank_output.meta.wcs = self.output_wcs
 
-        self.output_models = datamodels.ModelContainer()
+        self.output_models = datamodels.ModelContainer(open_models=False)
 
     def do_drizzle(self):
         """Pick the correct drizzling mode based on self.single
@@ -132,15 +146,26 @@ class ResampleData:
         Used for outlier detection
         """
         for exposure in self.input_models.models_grouped:
-            output_model = self.blank_output.copy()
+            output_model = self.blank_output
+            # Determine output file type from input exposure filenames
+            # Use this for defining the output filename
+            indx = exposure[0].meta.filename.rfind('.')
+            output_type = exposure[0].meta.filename[indx:]
+            output_root = '_'.join(exposure[0].meta.filename.replace(
+                output_type, '').split('_')[:-1])
+            output_model.meta.filename = f'{output_root}_outlier_i2d{output_type}'
 
             # Initialize the output with the wcs
             driz = gwcs_drizzle.GWCSDrizzle(output_model, pixfrac=self.pixfrac,
                                             kernel=self.kernel, fillval=self.fillval)
+
+            log.info(f"{len(exposure)} exposures to drizzle together")
             for img in exposure:
+                img = datamodels.open(img)
                 # TODO: should weight_type=None here?
                 inwht = resample_utils.build_driz_weight(img, weight_type=self.weight_type,
                                                          good_bits=self.good_bits)
+
                 # apply sky subtraction
                 blevel = img.meta.background.level
                 if not img.meta.background.subtracted and blevel is not None:
@@ -149,8 +174,19 @@ class ResampleData:
                     data = img.data
 
                 driz.add_image(data, img.meta.wcs, inwht=inwht)
+                del data
+                img.close()
 
-            self.output_models.append(output_model)
+            if not self.in_memory:
+                # Write out model to disk, then return filename
+                output_name = output_model.meta.filename
+                output_model.save(output_name)
+                log.info(f"Exposure {output_name} saved to file")
+                self.output_models.append(output_name)
+            else:
+                self.output_models.append(output_model.copy())
+            output_model.data *= 0.
+            output_model.wht *= 0.
 
         return self.output_models
 
@@ -181,16 +217,25 @@ class ResampleData:
             if not img.meta.background.subtracted and blevel is not None:
                 data = img.data - blevel
             else:
-                data = img.data
+                data = img.data.copy()
 
             driz.add_image(data, img.meta.wcs, inwht=inwht)
+            del data, inwht
 
         # Resample variances array in self.input_models to output_model
         self.resample_variance_array("var_rnoise", output_model)
         self.resample_variance_array("var_poisson", output_model)
         self.resample_variance_array("var_flat", output_model)
-        output_model.err = np.sqrt(output_model.var_rnoise + output_model.var_poisson
-                                   + output_model.var_flat)
+        output_model.err = np.sqrt(
+            np.nansum(
+                [
+                    output_model.var_rnoise,
+                    output_model.var_poisson,
+                    output_model.var_flat
+                ],
+                axis=0
+            )
+        )
 
         # TODO: The following two methods and calls should be moved upstream to
         # ResampleStep and ResampleSpecStep respectively
@@ -213,7 +258,7 @@ class ResampleData:
         This modifies output_model in-place.
         """
         output_wcs = output_model.meta.wcs
-        inverse_variance_sum = np.zeros_like(output_model.data)
+        inverse_variance_sum = np.full_like(output_model.data, np.nan)
 
         log.info(f"Resampling {name}")
         for model in self.input_models:
@@ -233,29 +278,35 @@ class ResampleData:
                 continue
 
             # Make input weight map of unity where there is science data
-            inwht = resample_utils.build_driz_weight(model, weight_type=None,
-                                                     good_bits="~NON_SCIENCE+REFERENCE_PIXEL")
+            inwht = resample_utils.build_driz_weight(
+                model,
+                weight_type=None,
+                good_bits="~NON_SCIENCE+REFERENCE_PIXEL"
+            )
 
             resampled_variance = np.zeros_like(output_model.data)
             outwht = np.zeros_like(output_model.data)
             outcon = np.zeros_like(output_model.con)
 
-            # Resample the variance array.  Use fillval=np.inf so that when we
-            # take the reciprocal for summing, it is zero where there is zero weight
+            # Resample the variance array. Fill "unpopulated" pixels with NaNs.
             self.drizzle_arrays(variance, inwht, model.meta.wcs,
                                 output_wcs, resampled_variance, outwht, outcon,
                                 pixfrac=self.pixfrac, kernel=self.kernel,
-                                fillval=np.inf)
+                                fillval=np.nan)
 
-            # Add the inverse of the resampled variance to a running sum
-            with np.errstate(divide="ignore"):
-                inverse_variance_sum += np.reciprocal(resampled_variance)
+            # Add the inverse of the resampled variance to a running sum.
+            # Update only pixels (in the running sum) with valid new values:
+            mask = resampled_variance > 0
+
+            inverse_variance_sum[mask] = np.nansum(
+                [inverse_variance_sum[mask], np.reciprocal(resampled_variance[mask])],
+                axis=0
+            )
 
         # We now have a sum of the inverse resampled variances.  We need the
         # inverse of that to get back to units of variance.
-        with np.errstate(divide="ignore"):
-            output_variance = np.reciprocal(inverse_variance_sum)
-        output_variance[~np.isfinite(output_variance)] = np.nan
+        output_variance = np.reciprocal(inverse_variance_sum)
+
         setattr(output_model, name, output_variance)
 
     def update_exposure_times(self, output_model):
@@ -381,7 +432,7 @@ class ResampleData:
         else:
             fillval = str(fillval)
 
-        if (insci.dtype > np.float32):
+        if insci.dtype > np.float32:
             insci = insci.astype(np.float32)
 
         # Add input weight image if it was not passed in
