@@ -30,11 +30,13 @@ class ResampleStep(Step):
         Single filename for either a single image or an association table.
     """
 
+    class_alias = "resample"
+
     spec = """
-        pixfrac = float(default=1.0)
-        kernel = string(default='square')
-        fillval = string(default='INDEF')
-        weight_type = option('ivm', 'exptime', default='ivm')
+        pixfrac = float(default=1.0) # change back to None when drizpar reference files are updated
+        kernel = string(default='square') # change back to None when drizpar reference files are updated
+        fillval = string(default='INDEF' ) # change back to None when drizpar reference files are updated
+        weight_type = option('ivm', 'exptime', None, default='ivm')  # change back to None when drizpar ref update
         output_shape = int_list(min=2, max=2, default=None)  # [x, y] order
         crpix = float_list(min=2, max=2, default=None)
         crval = float_list(min=2, max=2, default=None)
@@ -44,6 +46,7 @@ class ResampleStep(Step):
         single = boolean(default=False)
         blendheaders = boolean(default=True)
         allowed_memory = float(default=None)  # Fraction of memory to use for the combined image.
+        in_memory = boolean(default=True)
     """
 
     reference_file_types = ['drizpars']
@@ -63,6 +66,8 @@ class ResampleStep(Step):
                 output = None
         else:
             input_models = datamodels.ModelContainer([input])
+            input_models.asn_pool_name = input.meta.asn.pool_name
+            input_models.asn_table_name = input.meta.asn.table_name
             output = input.meta.filename
             self.blendheaders = False
 
@@ -72,21 +77,22 @@ class ResampleStep(Step):
             raise RuntimeError("Input {} is not a 2D image.".format(input_models[0]))
 
         # Get drizzle parameters reference file
+        self.wht_type = self.weight_type
         for reftype in self.reference_file_types:
             ref_filename = self.get_reference_file(input_models[0], reftype)
 
         if ref_filename != 'N/A':
             self.log.info('Drizpars reference file: {}'.format(ref_filename))
             kwargs = self.get_drizpars(ref_filename, input_models)
-
         else:
             # If there is no drizpars reffile
-            self.log.info("No DIRZPARS reffile")
+            self.log.info("No DRIZPARS reffile")
             kwargs = self._set_spec_defaults()
 
         kwargs['allowed_memory'] = self.allowed_memory
-        kwargs['weight_type'] = str(self.weight_type)
-        if self.weight_type == 'exptime':
+
+        # Issue a warning about the use of exptime weighting
+        if self.wht_type == 'exptime':
             self.log.warning("Use of EXPTIME weighting will result in incorrect")
             self.log.warning("propagated errors in the resampled product")
 
@@ -99,6 +105,7 @@ class ResampleStep(Step):
         kwargs['crval'] = _check_list_pars(self.crval, 'crval')
         kwargs['rotation'] = self.rotation
         kwargs['pscale'] = self.pixel_scale
+        kwargs['in_memory'] = self.in_memory
 
         # Call the resampling routine
         resamp = resample.ResampleData(input_models, output=output, **kwargs)
@@ -109,8 +116,9 @@ class ResampleStep(Step):
             util.update_s_region_imaging(model)
             model.meta.asn.pool_name = input_models.asn_pool_name
             model.meta.asn.table_name = input_models.asn_table_name
+            model.meta.resample.pixel_scale_ratio = self.pixel_scale_ratio
+            model.meta.resample.pixfrac = kwargs['pixfrac']
             self.update_phot_keywords(model)
-            model.meta.filetype = 'resampled'
 
         if len(result) == 1:
             result = result[0]
@@ -124,8 +132,6 @@ class ResampleStep(Step):
             model.meta.photometry.pixelarea_steradians *= self.pixel_scale_ratio**2
         if model.meta.photometry.pixelarea_arcsecsq is not None:
             model.meta.photometry.pixelarea_arcsecsq *= self.pixel_scale_ratio**2
-        model.meta.resample.pixel_scale_ratio = self.pixel_scale_ratio
-        model.meta.resample.pixfrac = self.pixfrac
 
     def get_drizpars(self, ref_filename, input_models):
         """
@@ -138,6 +144,7 @@ class ResampleStep(Step):
         pixfrac = float(default=None)
         kernel = string(default=None)
         fillval = string(default=None)
+        wht_type = option('ivm', 'exptime', None, default=None)
 
         Once the defaults are set from the reference file, if the user has
         used a resample.cfg file or run ResampleStep using command line args,
@@ -175,11 +182,13 @@ class ResampleStep(Step):
         # Define the keys to pull from drizpars reffile table.
         # All values should be None unless the user set them on the command
         # line or in the call to the step
+
         drizpars = dict(
             pixfrac=self.pixfrac,
             kernel=self.kernel,
             fillval=self.fillval,
-            pscale_ratio=self.pixel_scale_ratio,
+            wht_type=self.wht_type
+            # pscale_ratio=self.pixel_scale_ratio, # I think this can be removed JEM (??)
         )
 
         # For parameters that are set in drizpars table but not set by the
@@ -223,23 +232,29 @@ class ResampleStep(Step):
         if config.validate(Validator()):
             kwargs = config.dict()
 
+        if self.pixfrac is None:
+            self.pixfrac = 1.0
+        if self.kernel is None:
+            self.kernel = 'square'
+        if self.fillval is None:
+            self.fillval = 'INDEF'
         # Force definition of good bits
         kwargs['good_bits'] = GOOD_BITS
+        kwargs['pixfrac'] = self.pixfrac
+        kwargs['kernel'] = str(self.kernel)
+        kwargs['fillval'] = str(self.fillval)
+        #  self.weight_type has a default value of None
+        # The other instruments read this parameter from a reference file
+        if self.wht_type is None:
+            self.wht_type = 'ivm'
 
-        if kwargs['pixfrac'] is None:
-            kwargs['pixfrac'] = 1.0
-        if kwargs['kernel'] is None:
-            kwargs['kernel'] = 'square'
-        if kwargs['fillval'] is None:
-            kwargs['fillval'] = 'INDEF'
-        if kwargs['weight_type'] is None:
-            kwargs['weight_type'] = 'ivm'
+        kwargs['wht_type'] = str(self.wht_type)
         kwargs['pscale_ratio'] = self.pixel_scale_ratio
         kwargs.pop('pixel_scale_ratio')
 
         for k, v in kwargs.items():
-            if k in ['pixfrac', 'kernel', 'fillval', 'weight_type', 'pscale_ratio']:
-                log.info('  setting: %s=%s', k, repr(v))
+            if k in ['pixfrac', 'kernel', 'fillval', 'wht_type', 'pscale_ratio']:
+                log.info('  using: %s=%s', k, repr(v))
 
         return kwargs
 
