@@ -172,8 +172,8 @@ def build_driz_weight(model, weight_type=None, good_bits=None):
     dqmask = build_mask(model.dq, good_bits)
 
     if weight_type == 'ivm':
-        if (model.hasattr("var_rnoise") and model.var_rnoise is not None
-                and model.var_rnoise.shape == model.data.shape):
+        if (model.hasattr("var_rnoise") and model.var_rnoise is not None and
+                model.var_rnoise.shape == model.data.shape):
             with np.errstate(divide="ignore", invalid="ignore"):
                 inv_variance = model.var_rnoise**-1
             inv_variance[~np.isfinite(inv_variance)] = 1
@@ -199,7 +199,7 @@ def build_mask(dqarr, bitvalue):
     bitvalue = interpret_bit_flags(bitvalue, mnemonic_map=pixel)
 
     if bitvalue is None:
-        return (np.ones(dqarr.shape, dtype=np.uint8))
+        return np.ones(dqarr.shape, dtype=np.uint8)
     return np.logical_not(np.bitwise_and(dqarr, ~bitvalue)).astype(np.uint8)
 
 
