@@ -11,12 +11,16 @@ from stpipe import crds_client
 from stpipe import Step
 from stpipe import Pipeline
 from ..lib.suffix import remove_suffix
+import logging
+
+log = logging.getLogger(__name__)
+log.setLevel(logging.DEBUG)
 
 
 class JwstStep(Step):
 
     spec = """
-    output_ext         = string(default='.fits')     # Default type of output
+    output_ext = string(default='.fits')  # Output file type
     """
 
     @classmethod
@@ -82,6 +86,8 @@ class JwstStep(Step):
                         getattr(result.meta.ref_file, ref_name).name = filename
                 result.meta.ref_file.crds.sw_version = crds_client.get_svn_version()
                 result.meta.ref_file.crds.context_used = crds_client.get_context_used(result.crds_observatory)
+                if self.parent is None:
+                    log.info(f"Results used CRDS context: {result.meta.ref_file.crds.context_used}")
 
     def record_step_status(self, datamodel, cal_step, success=True):
         """Record whether or not a step completed in meta.cal_step
@@ -119,4 +125,6 @@ class JwstStep(Step):
 # be a subclass of JwstStep so that it will pass checks
 # when constructing a pipeline using JwstStep class methods.
 class JwstPipeline(Pipeline, JwstStep):
-    pass
+    def finalize_result(self, result, reference_files_used):
+        if isinstance(result, DataModel):
+            log.info(f"Results used CRDS context: {crds_client.get_context_used(result.crds_observatory)}")
