@@ -10,17 +10,33 @@ from astropy.table import Table
 from astropy import units as u
 from astropy.coordinates import SkyCoord
 from tweakwcs.imalign import align_wcs
-from tweakwcs.tpwcs import JWSTgWCS
-from tweakwcs.matchutils import TPMatch
+from tweakwcs.correctors import JWSTWCSCorrector
+from tweakwcs.matchutils import XYXYMatch
 
 # LOCAL
 from ..stpipe import Step
 from .. import datamodels
-
+from ..assign_wcs.util import update_fits_wcsinfo
 from . import astrometric_utils as amutils
 from .tweakreg_catalog import make_tweakreg_catalog
 
 
+def _oxford_or_str_join(str_list):
+    nelem = len(str_list)
+    if not nelem:
+        return 'N/A'
+    str_list = list(map(repr, str_list))
+    if nelem == 1:
+        return str_list
+    elif nelem == 2:
+        return str_list[0] + ' or ' + str_list[1]
+    else:
+        return ', '.join(map(repr, str_list[:-1])) + ', or ' + repr(str_list[-1])
+
+
+SINGLE_GROUP_REFCAT = ['GAIADR2', 'GAIADR1']
+_SINGLE_GROUP_REFCAT_STR = _oxford_or_str_join(SINGLE_GROUP_REFCAT)
+
 __all__ = ['TweakRegStep']
 
 
@@ -30,30 +46,47 @@ class TweakRegStep(Step):
     input images.
     """
 
-    spec = """
+    class_alias = "tweakreg"
+
+    spec = f"""
         save_catalogs = boolean(default=False) # Write out catalogs?
         catalog_format = string(default='ecsv') # Catalog output file format
         kernel_fwhm = float(default=2.5) # Gaussian kernel FWHM in pixels
         snr_threshold = float(default=10.0) # SNR threshold above the bkg
-        brightest = integer(default=1000) # Keep top ``brightest`` objects
+        sharplo = float(default=0.2) # The lower bound on sharpness for object detection.
+        sharphi = float(default=1.0) # The upper bound on sharpness for object detection.
+        roundlo = float(default=-1.0) # The lower bound on roundness for object detection.
+        roundhi = float(default=1.0) # The upper bound on roundness for object detection.
+        brightest = integer(default=200) # Keep top ``brightest`` objects
         peakmax = float(default=None) # Filter out objects with pixel values >= ``peakmax``
+        bkg_boxsize = integer(default=400) # The background mesh box size in pixels.
         enforce_user_order = boolean(default=False) # Align images in user specified order?
         expand_refcat = boolean(default=False) # Expand reference catalog with new sources?
         minobj = integer(default=15) # Minimum number of objects acceptable for matching
-        searchrad = float(default=1.0) # The search radius in arcsec for a match
+        searchrad = float(default=2.0) # The search radius in arcsec for a match
         use2dhist = boolean(default=True) # Use 2d histogram to find initial offset?
-        separation = float(default=0.5) # Minimum object separation in arcsec
-        tolerance = float(default=1.0) # Matching tolerance for xyxymatch in arcsec
+        separation = float(default=1.0) # Minimum object separation in arcsec
+        tolerance = float(default=0.7) # Matching tolerance for xyxymatch in arcsec
         xoffset = float(default=0.0), # Initial guess for X offset in arcsec
         yoffset = float(default=0.0) # Initial guess for Y offset in arcsec
-        fitgeometry = option('shift', 'rshift', 'rscale', 'general', default='general') # Fitting geometry
+        fitgeometry = option('shift', 'rshift', 'rscale', 'general', default='rshift') # Fitting geometry
         nclip = integer(min=0, default=3) # Number of clipping iterations in fit
         sigma = float(min=0.0, default=3.0) # Clipping limit in sigma units
         align_to_gaia = boolean(default=False)  # Align to GAIA catalog
-        gaia_catalog = option('GAIADR2', 'GAIADR1', default='GAIADR2')
+        gaia_catalog = string(default='GAIADR2')  # Catalog file name or one of: {_SINGLE_GROUP_REFCAT_STR}
         min_gaia = integer(min=0, default=5) # Min number of GAIA sources needed
         save_gaia_catalog = boolean(default=False)  # Write out GAIA catalog as a separate product
         output_use_model = boolean(default=True)  # When saving use `DataModel.meta.filename`
+        abs_minobj = integer(default=15) # Minimum number of objects acceptable for matching when performing absolute astrometry
+        abs_searchrad = float(default=6.0) # The search radius in arcsec for a match when performing absolute astrometry
+        # We encourage setting this parameter to True. Otherwise, xoffset and yoffset will be set to zero.
+        abs_use2dhist = boolean(default=True) # Use 2D histogram to find initial offset when performing absolute astrometry?
+        abs_separation = float(default=0.1) # Minimum object separation in arcsec when performing absolute astrometry
+        abs_tolerance = float(default=0.7) # Matching tolerance for xyxymatch in arcsec when performing absolute astrometry
+        # Fitting geometry when performing absolute astrometry
+        abs_fitgeometry = option('shift', 'rshift', 'rscale', 'general', default='rshift')
+        abs_nclip = integer(min=0, default=3) # Number of clipping iterations in fit when performing absolute astrometry
+        abs_sigma = float(min=0.0, default=3.0) # Clipping limit in sigma units when performing absolute astrometry
     """
 
     reference_file_types = []
@@ -78,9 +111,13 @@ class TweakRegStep(Step):
 
         # Build the catalogs for input images
         for image_model in images:
+            # source finding
             catalog = make_tweakreg_catalog(
                 image_model, self.kernel_fwhm, self.snr_threshold,
-                brightest=self.brightest, peakmax=self.peakmax
+                sharplo=self.sharplo, sharphi=self.sharphi,
+                roundlo=self.roundlo, roundhi=self.roundhi,
+                brightest=self.brightest, peakmax=self.peakmax,
+                bkg_boxsize=self.bkg_boxsize
             )
 
             # filter out sources outside the WCS bounding box
@@ -133,7 +170,7 @@ class TweakRegStep(Step):
                       .format(len(grp_img)))
         self.log.info("Image groups:")
 
-        if len(grp_img) == 1:
+        if len(grp_img) == 1 and not self.align_to_gaia:
             self.log.info("* Images in GROUP 1:")
             for im in grp_img[0]:
                 self.log.info("     {}".format(im.meta.filename))
@@ -150,75 +187,102 @@ class TweakRegStep(Step):
                 del model.catalog
             return input
 
-        # create a list of WCS-Catalog-Images Info and/or their Groups:
-        imcats = []
-        for g in grp_img:
-            if len(g) == 0:
-                raise AssertionError("Logical error in the pipeline code.")
-            else:
-                group_name = _common_name(g)
-                wcsimlist = list(map(self._imodel2wcsim, g))
-                # Remove the attached catalogs
-                for model in g:
-                    del model.catalog
-                self.log.info("* Images in GROUP '{}':".format(group_name))
-                for im in wcsimlist:
-                    im.meta['group_id'] = group_name
-                    self.log.info("     {}".format(im.meta['name']))
-                imcats.extend(wcsimlist)
+        elif len(grp_img) > 1:
 
-        self.log.info('')
+            # create a list of WCS-Catalog-Images Info and/or their Groups:
+            imcats = []
+            for g in grp_img:
+                if len(g) == 0:
+                    raise AssertionError("Logical error in the pipeline code.")
+                else:
+                    group_name = _common_name(g)
+                    wcsimlist = list(map(self._imodel2wcsim, g))
+                    # Remove the attached catalogs
+                    for model in g:
+                        del model.catalog
+                    self.log.info("* Images in GROUP '{}':".format(group_name))
+                    for im in wcsimlist:
+                        im.meta['group_id'] = group_name
+                        self.log.info("     {}".format(im.meta['name']))
+                    imcats.extend(wcsimlist)
 
-        # align images:
-        tpmatch = TPMatch(
-            searchrad=self.searchrad,
-            separation=self.separation,
-            use2dhist=self.use2dhist,
-            tolerance=self.tolerance,
-            xoffset=self.xoffset,
-            yoffset=self.yoffset
-        )
+            self.log.info('')
 
-        try:
-            align_wcs(
-                imcats,
-                refcat=None,
-                enforce_user_order=self.enforce_user_order,
-                expand_refcat=self.expand_refcat,
-                minobj=self.minobj,
-                match=tpmatch,
-                fitgeom=self.fitgeometry,
-                nclip=self.nclip,
-                sigma=(self.sigma, 'rmse')
+            # align images:
+            xyxymatch = XYXYMatch(
+                searchrad=self.searchrad,
+                separation=self.separation,
+                use2dhist=self.use2dhist,
+                tolerance=self.tolerance,
+                xoffset=self.xoffset,
+                yoffset=self.yoffset
             )
 
-        except ValueError as e:
-            msg = e.args[0]
-            if (msg == "Too few input images (or groups of images) with "
-                    "non-empty catalogs."):
-                # we need at least two exposures to perform image alignment
-                self.log.warning(msg)
-                self.log.warning("At least two exposures are required for "
-                                 "image alignment.")
-                self.log.warning("Nothing to do. Skipping 'TweakRegStep'...")
-                self.skip = True
-                for model in images:
-                    model.meta.cal_step.tweakreg = "SKIPPED"
-                return images
+            try:
+                align_wcs(
+                    imcats,
+                    refcat=None,
+                    enforce_user_order=self.enforce_user_order,
+                    expand_refcat=self.expand_refcat,
+                    minobj=self.minobj,
+                    match=xyxymatch,
+                    fitgeom=self.fitgeometry,
+                    nclip=self.nclip,
+                    sigma=(self.sigma, 'rmse')
+                )
 
-            else:
-                raise e
+            except ValueError as e:
+                msg = e.args[0]
+                if (msg == "Too few input images (or groups of images) with "
+                        "non-empty catalogs."):
+                    # we need at least two exposures to perform image alignment
+                    self.log.warning(msg)
+                    self.log.warning("At least two exposures are required for "
+                                     "image alignment.")
+                    self.log.warning("Nothing to do. Skipping 'TweakRegStep'...")
+                    for model in images:
+                        model.meta.cal_step.tweakreg = "SKIPPED"
+                    if not self.align_to_gaia:
+                        self.skip = True
+                        return images
+                else:
+                    raise e
 
-        for imcat in imcats:
-            wcs = imcat.meta['image_model'].meta.wcs
-            twcs = imcat.wcs
-            if not self.fit_quality_is_good(wcs, twcs):
-                self.log.warning(f"WCS has been tweaked by more than {10 * self.tolerance} arcsec")
-                self.log.warning("Skipping 'TweakRegStep'...")
-                self.skip = True
-                for model in images:
-                    model.meta.cal_step.tweakreg = "SKIPPED"
-                return images
+            except RuntimeError as e:
+                msg = e.args[0]
+                if msg.startswith("Number of output coordinates exceeded allocation"):
+                    # we need at least two exposures to perform image alignment
+                    self.log.error(msg)
+                    self.log.error("Multiple sources within specified tolerance "
+                                   "matched to a single reference source. Try to "
+                                   "adjust 'tolerance' and/or 'separation' parameters.")
+                    self.log.warning("Skipping 'TweakRegStep'...")
+                    self.skip = True
+                    for model in images:
+                        model.meta.cal_step.tweakreg = "SKIPPED"
+                    return images
+                else:
+                    raise e
+
+            for imcat in imcats:
+                model = imcat.meta['image_model']
+                if model.meta.cal_step.tweakreg == "SKIPPED":
+                    continue
+                wcs = model.meta.wcs
+                twcs = imcat.wcs
+                if not self._is_wcs_correction_small(wcs, twcs):
+                    # Large corrections are typically a result of source
+                    # mis-matching or poorly-conditioned fit. Skip such models.
+                    self.log.warning(f"WCS has been tweaked by more than {10 * self.tolerance} arcsec")
+
+                    for model in images:
+                        model.meta.cal_step.tweakreg = "SKIPPED"
+                    if self.align_to_gaia:
+                        self.log.warning("Skipping relative alignment (stage 1)...")
+                    else:
+                        self.log.warning("Skipping 'TweakRegStep'...")
+                        self.skip = True
+                        return images
 
         if self.align_to_gaia:
             # Get catalog of GAIA sources for the field
@@ -231,29 +295,51 @@ class TweakRegStep(Step):
                 output_name = 'fit_{}_ref.ecsv'.format(self.gaia_catalog.lower())
             else:
                 output_name = None
-            ref_cat = amutils.create_astrometric_catalog(images,
-                                                         self.gaia_catalog,
-                                                         output=output_name)
+
+            # initial shift to be used with absolute astrometry
+            self.abs_xoffset = 0
+            self.abs_yoffset = 0
+
+            self.gaia_catalog = self.gaia_catalog.strip()
+            gaia_cat_name = self.gaia_catalog.upper()
+
+            if gaia_cat_name in SINGLE_GROUP_REFCAT:
+                ref_cat = amutils.create_astrometric_catalog(
+                    images,
+                    gaia_cat_name,
+                    output=output_name
+                )
+
+            elif path.isfile(self.gaia_catalog):
+                ref_cat = Table.read(self.gaia_catalog)
+
+            else:
+                raise ValueError("'gaia_catalog' must be a path to an "
+                                 "existing file name or one of the supported "
+                                 f"reference catalogs: {_SINGLE_GROUP_REFCAT_STR}.")
 
             # Check that there are enough GAIA sources for a reliable/valid fit
             num_ref = len(ref_cat)
             if num_ref < self.min_gaia:
-                msg = "Not enough GAIA sources for a fit: {}\n".format(num_ref)
-                msg += "Skipping alignment to {} astrometric catalog!\n".format(self.gaia_catalog)
                 # Raise Exception here to avoid rest of code in this try block
-                self.log.warning(msg)
+                self.log.warning(
+                    f"Not enough sources ({num_ref}) in the reference catalog "
+                    "for the single-group alignment step to perform a fit. "
+                    f"Skipping alignment to the {self.gaia_catalog} reference "
+                    "catalog!"
+                )
             else:
                 # align images:
                 # Update to separation needed to prevent confusion of sources
                 # from overlapping images where centering is not consistent or
                 # for the possibility that errors still exist in relative overlap.
-                tpmatch_gaia = TPMatch(
-                    searchrad=self.searchrad * 3.0,
-                    separation=self.separation / 10.0,
-                    use2dhist=self.use2dhist,
-                    tolerance=self.tolerance,
-                    xoffset=0.0,
-                    yoffset=0.0
+                xyxymatch_gaia = XYXYMatch(
+                    searchrad=self.abs_searchrad,
+                    separation=self.abs_separation,
+                    use2dhist=self.abs_use2dhist,
+                    tolerance=self.abs_tolerance,
+                    xoffset=self.abs_xoffset,
+                    yoffset=self.abs_yoffset
                 )
 
                 # Set group_id to same value so all get fit as one observation
@@ -272,15 +358,16 @@ class TweakRegStep(Step):
                     refcat=ref_cat,
                     enforce_user_order=True,
                     expand_refcat=False,
-                    minobj=self.minobj,
-                    match=tpmatch_gaia,
-                    fitgeom=self.fitgeometry,
-                    nclip=self.nclip,
-                    sigma=(self.sigma, 'rmse')
+                    minobj=self.abs_minobj,
+                    match=xyxymatch_gaia,
+                    fitgeom=self.abs_fitgeometry,
+                    nclip=self.abs_nclip,
+                    sigma=(self.abs_sigma, 'rmse')
                 )
 
         for imcat in imcats:
-            imcat.meta['image_model'].meta.cal_step.tweakreg = 'COMPLETE'
+            image_model = imcat.meta['image_model']
+            image_model.meta.cal_step.tweakreg = 'COMPLETE'
 
             # retrieve fit status and update wcs if fit is successful:
             if 'SUCCESS' in imcat.meta.get('fit_info')['status']:
@@ -298,22 +385,24 @@ class TweakRegStep(Step):
                     #       for end-user searches.
                     imcat.wcs.name = "FIT-LVL3-{}".format(self.gaia_catalog)
 
-                imcat.meta['image_model'].meta.wcs = imcat.wcs
+                image_model.meta.wcs = imcat.wcs
 
-                """
                 # Also update FITS representation in input exposures for
                 # subsequent reprocessing by the end-user.
-                # Not currently enabled, but may be requested later...
-                gwcs_header = imcat.wcs.to_fits_sip(max_pix_error=0.1,
-                                                max_inv_pix_error=0.1,
-                                                degree=3,
-                                                npoints=128)
-                imcat.meta['image_model'].wcs = wcs.WCS(header=gwcs_header)
-                """
+                try:
+                    update_fits_wcsinfo(
+                        image_model,
+                        max_pix_error=0.005
+                    )
+                except (ValueError, RuntimeError) as e:
+                    self.log.warning(
+                        "Failed to update 'meta.wcsinfo' with FITS SIP "
+                        f'approximation. Reported error is:\n"{e.args[0]}"'
+                    )
 
         return images
 
-    def fit_quality_is_good(self, wcs, twcs):
+    def _is_wcs_correction_small(self, wcs, twcs):
         """Check that the newly tweaked wcs hasn't gone off the rails"""
         tolerance = 10.0 * self.tolerance * u.arcsec
 
@@ -353,7 +442,7 @@ class TweakRegStep(Step):
 
         # create WCSImageCatalog object:
         refang = image_model.meta.wcsinfo.instance
-        im = JWSTgWCS(
+        im = JWSTWCSCorrector(
             wcs=image_model.meta.wcs,
             wcsinfo={'roll_ref': refang['roll_ref'],
                      'v2_ref': refang['v2_ref'],
